<?php namespace Premmerce\Optimizer\Admin;

use Premmerce\Optimizer\Cache\Cache;
use Premmerce\SDK\V2\FileManager\FileManager;
use Premmerce\SDK\V2\Notifications\AdminNotifier;

/**
 * Class Admin
 *
 * @package Premmerce\Optimizer\Admin
 */
class Admin
{
    /**
     * @var FileManager
     */
    private $fileManager;

    /**
     * @var Settings
     */
    private $settings;

    /**
     * @var Cache
     */
    private $cache;

    /**
     * @var AdminNotifier
     */
    private $notifier;

    /**
     * Admin constructor.
     *
     * Register menu items and handlers
     *
     * @param FileManager $fileManager
     * @param Cache $cache
     */
    public function __construct(FileManager $fileManager, Cache $cache)
    {
        $this->fileManager = $fileManager;
        $this->cache       = $cache;

        $this->notifier = new AdminNotifier();
        $this->settings = new Settings();

        add_action('admin_post_premmerce_optimizer_cache_clear', array($this, 'clearCacheRedirect'));
        add_action('admin_menu', array($this, 'addMenuPage'));
        add_action('admin_init', array($this->settings, 'initSettings'));


        add_action('pre_set_theme_mod_nav_menu_locations', array($this, 'clearCacheOnChangeMenuLocation'), 10, 2);
        add_action('wp_update_nav_menu', array($this->cache, 'clear'));
        add_action('switch_theme', array($this->cache, 'clear'));
    }

    public function clearCacheOnChangeMenuLocation($value, $oldValue)
    {
        if ($value !== $oldValue) {
            $this->cache->clear();
        }

        return $value;
    }

    /**
     * Add submenu to premmerce menu page
     */
    public function addMenuPage()
    {
        global $admin_page_hooks;

        $premmerceMenuExists = isset($admin_page_hooks['premmerce']);

        if (! $premmerceMenuExists) {
            $svg = '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="20" height="16" style="fill:#82878c" viewBox="0 0 20 16"><g id="Rectangle_7"> <path d="M17.8,4l-0.5,1C15.8,7.3,14.4,8,14,8c0,0,0,0,0,0H8h0V4.3C8,4.1,8.1,4,8.3,4H17.8 M4,0H1C0.4,0,0,0.4,0,1c0,0.6,0.4,1,1,1 h1.7C2.9,2,3,2.1,3,2.3V12c0,0.6,0.4,1,1,1c0.6,0,1-0.4,1-1V1C5,0.4,4.6,0,4,0L4,0z M18,2H7.3C6.6,2,6,2.6,6,3.3V12 c0,0.6,0.4,1,1,1c0.6,0,1-0.4,1-1v-1.7C8,10.1,8.1,10,8.3,10H14c1.1,0,3.2-1.1,5-4l0.7-1.4C20,4,20,3.2,19.5,2.6 C19.1,2.2,18.6,2,18,2L18,2z M14,11h-4c-0.6,0-1,0.4-1,1c0,0.6,0.4,1,1,1h4c0.6,0,1-0.4,1-1C15,11.4,14.6,11,14,11L14,11z M14,14 c-0.6,0-1,0.4-1,1c0,0.6,0.4,1,1,1c0.6,0,1-0.4,1-1C15,14.4,14.6,14,14,14L14,14z M4,14c-0.6,0-1,0.4-1,1c0,0.6,0.4,1,1,1 c0.6,0,1-0.4,1-1C5,14.4,4.6,14,4,14L4,14z"/></g></svg>';
            $svg = 'data:image/svg+xml;base64,' . base64_encode($svg);

            add_menu_page(
                'Premmerce',
                'Premmerce',
                'manage_options',
                'premmerce',
                '',
                $svg
            );
        }

        add_submenu_page(
            'premmerce',
            __('Performance', 'premmerce-filter'),
            __('Performance', 'premmerce-filter'),
            'manage_options',
            Settings::PAGE,
            array($this, 'options')
        );

        if (! $premmerceMenuExists) {
            global $submenu;
            unset($submenu['premmerce'][0]);
        }
    }

    public function clearCacheRedirect()
    {
        $this->cache->clear();
        $this->notifier->flash(__('Cache cleared', 'premmerce-performance-optimizer'), AdminNotifier::SUCCESS, true);
        wp_redirect(wp_get_referer());
    }

    public function options()
    {
        $this->fileManager->includeTemplate('admin/options.php', array(
            'settings' => $this->settings
        ));
    }
}
