<?php namespace Premmerce\Optimizer\Admin;

class Settings
{
    const OPTION = 'premmerce_performance_optimizer';

    const OPTION_GROUP = 'premmerce_performance_optimizer_group';

    const PAGE = 'premmerce-performance-optimizer';

    private $options;

    public function initSettings()
    {
        register_setting(self::OPTION_GROUP, self::OPTION);

        add_settings_section('cache', __('Cache', 'premmerce-performance-optimizer'), null, self::PAGE);

        add_settings_field(
            'cache_menus',
            __('Cache menus', 'premmerce-performance-optimizer'),
            array($this, 'checkbox'),
            self::PAGE,
            'cache',
            array(
                'label_for' => self::OPTION . '[cache_menus]',
                'name'      => 'cache_menus'
            )
        );

        add_settings_field('clear_cache', '', array($this, 'clearCache'), self::PAGE, 'cache');

        add_settings_section('optimization', __('Optimization', 'premmerce-performance-optimizer'), null, self::PAGE);


        add_settings_field(
            'optimize_woocommerce',
            __('Optimize WooCommerce', 'premmerce-performance-optimizer'),
            array($this, 'checkbox'),
            self::PAGE,
            'optimization',
            array(
                'label_for' => self::OPTION . '[optimize_woocommerce]',
                'name'      => 'optimize_woocommerce'
            )
        );

        add_settings_field(
            'optimize_variable_products',
            __('Optimize Variable Products', 'premmerce-performance-optimizer'),
            array($this, 'checkbox'),
            self::PAGE,
            'optimization',
            array(
                'label_for' => self::OPTION . '[optimize_variable_products]',
                'name'      => 'optimize_variable_products'
            )
        );
    }

    public function show()
    {
        print('<form action="' . admin_url('options.php') . '" method="post">');

        settings_errors();

        settings_fields(self::OPTION_GROUP);

        do_settings_sections(self::PAGE);

        submit_button();

        print('</form>');
    }

    public function clearCache()
    {
        vprintf('<a class="button" href="%s">%s</a>', array(
            wp_nonce_url(
                admin_url('admin-post.php?action=premmerce_optimizer_cache_clear'),
                'premmerce_optimizer_cache_clear'
            ),
            __('Clear cache', 'premmerce-performance-optimizer')

        ));
    }

    public function checkbox($args)
    {
        $labelFor = $args['label_for'];
        $name     = $args['name'];
        printf(
            '<input type="checkbox" name="%1$s" id="%1$s" %2$s >',
            $labelFor,
            $this->getOption($name) ? 'checked' : ''
        );
    }

    /**
     * @param string $key
     * @param mixed|null $default
     *
     * @return mixed|null
     */
    public function getOption($key, $default = null)
    {
        if (! isset($this->options)) {
            $this->options = get_option(self::OPTION);
        }

        return isset($this->options[$key]) ? $this->options[$key] : $default;
    }
}
