<?php namespace Premmerce\Optimizer;

use Premmerce\Optimizer\Admin\Settings;
use Premmerce\Optimizer\Cache\FileSystemCache;
use Premmerce\SDK\V2\FileManager\FileManager;
use Premmerce\Optimizer\Admin\Admin;
use Premmerce\Optimizer\Frontend\Frontend;
use Psr\SimpleCache\CacheInterface;

/**
 * Class OptimizerPlugin
 *
 * @package Premmerce\Optimizer
 */
class OptimizerPlugin
{
    /**
     * @var FileManager
     */
    private $fileManager;

    const VERSION = '1.1';

    /**
     * @var CacheInterface
     */
    private $cache;

    /**
     * OptimizerPlugin constructor.
     *
     * @param string $mainFile
     */
    public function __construct($mainFile)
    {
        $this->fileManager = new FileManager($mainFile, 'premmerce-performance-optimizer');

        $dir = wp_upload_dir()['basedir'] . '/cache/premmerce-performance-optimizer/';

        $this->cache = new FileSystemCache($dir);

        add_action('plugins_loaded', array($this, 'loadTextDomain'));
    }

    /**
     * Run plugin part
     */
    public function run()
    {
        if (is_admin()) {
            new Admin($this->fileManager, $this->cache);
        } else {
            new Frontend($this->fileManager, $this->cache);
        }
    }

    /**
     * Load plugin translations
     */
    public function loadTextDomain()
    {
        $name = $this->fileManager->getPluginName();
        load_plugin_textdomain('premmerce-performance-optimizer', false, $name . '/languages/');
    }

    /**
     * Fired when the plugin is activated
     */
    public function activate()
    {
        $option = get_option(Settings::OPTION);

        if (! is_array($option)) {
            update_option(Settings::OPTION, array(
                'cache_menus'                => 'on',
                'optimize_woocommerce'       => 'on',
                'optimize_variable_products' => 'on',
            ));
        }
    }

    /**
     * Fired when the plugin is deactivated
     */
    public function deactivate()
    {
        $this->cache->clear();
    }

    /**
     * Fired during plugin uninstall
     */
    public static function uninstall()
    {
    }
}
