<?php namespace Premmerce\Optimizer\WooCommerce\Proxy;

use WC_Product_Variable;

class ProductVariableLite extends WC_Product_Variable
{
    private $childrenCache = array();

    /**
     * Get an array of available variations for the current product.
     *
     * @return array
     * @throws \WC_Data_Exception
     */
    public function get_available_variations()
    {
        $available_variations = array();

        if (isset($this->childrenCache[$this->get_id()])) {
            return $this->childrenCache[$this->get_id()];
        }

        foreach ($this->get_children() as $child_id) {
            $variation = new ProductVariationLite($child_id, $this);

            if (! $variation || ! $variation->exists() || ('yes' === get_option('woocommerce_hide_out_of_stock_items') && ! $variation->is_in_stock())) {
                continue;
            }

            if (! $variation->variation_is_visible()) {
                continue;
            }

            $available_variations[] = $this->get_available_variation($variation);
        }

        $available_variations = array_filter($available_variations);

        $this->childrenCache[$this->get_id()] = $available_variations;

        return $available_variations;
    }
}
