<?php namespace Premmerce\Optimizer\WooCommerce\Proxy;

class ProductVariationLite extends \WC_Product_Variation
{
    /**
     * @var \WC_Product_Variable
     */
    private $parent;

    private $meta = array();

    /**
     * ProductVariation constructor.
     *
     * @param $id
     * @param \WC_Product_Variable $parent
     *
     * @throws \WC_Data_Exception
     */
    public function __construct($id, $parent)
    {
        $this->id     = $id;
        $this->parent = $parent;
        $meta         = get_post_meta($id);

        foreach ($meta as $key => $item) {
            if (!empty($item[0])) {
                $this->meta[ $key ] = $item[0];
            }
        }

        $this->set_data();
    }

    /**
     * @throws \WC_Data_Exception
     */
    protected function set_data()
    {
        $parent = $this->parent;

        $this->set_props(
            array(
                'name'            => $parent->get_title(),
                'slug'            => $parent->get_slug(),
                'date_created'    => $parent->get_date_created(),
                'date_modified'   => $parent->get_date_modified(),
                'menu_order'      => $parent->get_menu_order(),
                'reviews_allowed' => $parent->get_reviews_allowed(),
                'parent_id'       => $this->parent->get_id(),
            )
        );

        $this->set_props(
            array(
                'status'            => $parent->get_status(),
                'description'       => $this->meta('_variation_description'),
                'regular_price'     => $this->meta('_regular_price'),
                'sale_price'        => $this->meta('_sale_price'),
                'date_on_sale_from' => $this->meta('_sale_price_dates_from'),
                'date_on_sale_to'   => $this->meta('_sale_price_dates_to'),
                'manage_stock'      => $this->meta('_manage_stock'),
                'stock_status'      => $this->meta('_stock_status'),
                'shipping_class_id' => $parent->get_shipping_class_id(),
                'virtual'           => $this->meta('_virtual'),
                'downloadable'      => $this->meta('_downloadable'),
                'gallery_image_ids' => $this->meta('_product_image_gallery'),
                'download_limit'    => $this->meta('_download_limit'),
                'download_expiry'   => $this->meta('_download_expiry'),
                'image_id'          => $this->meta('_thumbnail_id'),
                'backorders'        => $this->meta('_backorders'),
                'sku'               => $this->meta('_sku'),
                'stock_quantity'    => $this->meta('_stock'),
                'weight'            => $this->meta('_weight'),
                'length'            => $this->meta('_length'),
                'width'             => $this->meta('_width'),
                'height'            => $this->meta('_height'),
                'tax_class'         => $this->meta('_tax_class', 'parent'),
            )
        );

        if ($this->is_on_sale('edit')) {
            $this->set_price($this->get_sale_price('edit'));
        } else {
            $this->set_price($this->get_regular_price('edit'));
        }


        $this->set_parent_data(
            array(
                'title'              => $parent->get_title(),
                'status'             => $parent->get_status(),
                'sku'                => $parent->get_sku(),
                'manage_stock'       => $parent->get_manage_stock(),
                'backorders'         => $parent->get_backorders(),
                'stock_quantity'     => $parent->get_stock_quantity(),
                'weight'             => $parent->get_weight(),
                'length'             => $parent->get_length(),
                'width'              => $parent->get_width(),
                'height'             => $parent->get_height(),
                'tax_class'          => $parent->get_tax_class(),
                'shipping_class_id'  => $parent->get_shipping_class_id(),
                'image_id'           => $parent->get_image_id(),
                'purchase_note'      => $parent->get_purchase_note(),
                'catalog_visibility' => $parent->get_catalog_visibility(),
            )
        );

        $this->set_sold_individually($parent->get_sold_individually());
        $this->set_tax_status($parent->get_tax_status());
        $this->set_cross_sell_ids($parent->get_cross_sell_ids());

        $this->set_attributes($this->wc_get_variation_attributes());

        $this->set_object_read(true);
    }

    public function meta($key, $default = null)
    {
        return isset($this->meta[ $key ])? $this->meta[ $key ] : $default;
    }

    private function wc_get_variation_attributes()
    {
        $parent_attributes    = $this->parent->get_attributes();
        $variation_attributes = array();

        /** @var \WC_Product_Attribute $attribute */
        foreach ($parent_attributes as $attribute_name => $attribute) {
            if ($attribute->get_variation()) {
                $attribute                          = 'attribute_' . sanitize_title($attribute->get_name());
                $variation_attributes[ $attribute ] = $this->meta($attribute, '');
            }
        }

        return $variation_attributes;
    }
}
